#!/bin/zsh
#   Author        : Levent Aydinbakar
#   Date          : 16-21-03---08-10-2024
#   Last Modified : 14-12-51---16-10-2024

# List the files in the current working directory using 'ls'
echo "You are currently at $(pwd)"
echo ""
echo "The following files are currently located in your directory ($(pwd))"
echo ""

ls --color=auto

echo ""
echo ""
echo "Press ctrl+c to cancel."
echo "Size is being calculated..."
sleep 2
echo ""
echo "Please wait..."
sleep 10
echo ""
echo ""

# Calculate the total size of the current directory (excluding directories)
TOTAL_SIZE_BYTES=$(du -sb . | cut -f1)
MAX_SIZE=$((5 * 1024 * 1024))  # 5 MB in bytes

# If the total size exceeds 5 MB, exit the script with a warning
if [ "$TOTAL_SIZE_BYTES" -gt "$MAX_SIZE" ]; then
    echo "ERROR: The total size of your files exceeds 5 MB."
	echo ""
	echo "Currently you are at " $(pwd)
	echo ""
	echo "If you are sure it is right place to submit your assignment, clean your directory before submitting. Lower the size below 5 MB."
	echo ""
    echo "If it is wrong directory, please locate your teminal to the correct folder before running submitAssignment.sh command."
	echo ""
	echo "Use cd ~/Assignment1 for example."
	echo ""
	echo -e "\e[31mPLEASE READ THE ALL MESSAGE ABOVE!\e[0m"

    exit 1
fi

# Show the total size of the files in MB for feedback
TOTAL_SIZE_MB=$(du -sh . | cut -f1)
echo "Total size of the files: $TOTAL_SIZE_MB"
echo "Are you sure you want to submit these files? (yes/no)"
read CONFIRM_SUBMIT

# If the student does not confirm, exit the script
if [[ "$CONFIRM_SUBMIT" != "yes" && "$CONFIRM_SUBMIT" != "y" ]]; then
    echo "Submission canceled."
	echo ""
    echo "Please locate your teminal to the correct folder before running submitAssignment.sh command."
	echo ""
	echo "Use cd ~/Assignment1 for example."
    exit 1
fi

# Ask for the student ID (assumes repository name is based on student ID)
echo "Enter your student ID (e.g., 123456789):"
read STUDENT_ID

echo "Enter your GitLab User Name (WITHOUT @ogr.btu.edu.tr):"
read STUDENT_USER_NAME

# Define the repository URL without embedding the credentials
REPO_URL="https://gitlab.com/laydinbakar/$STUDENT_ID.git"

git config --global user.email "$STUDENT_ID@ogr.btu.edu.tr"
git config --global user.name "$STUDENT_USER_NAME"


# Clone the student's repository (Git will prompt for username and password)
echo "Cloning repository $REPO_URL..."
git clone "$REPO_URL"

# Check if the clone was successful
if [ $? -eq 0 ]; then
    echo "Repository cloned successfully."
else
    echo "Error: Could not clone the repository. Please check your credentials and repository name."
    exit 1
fi

# Change into the cloned repository directory
cd "$STUDENT_ID" || exit

# Ask the student which assignment they are submitting (1, 2, 3, etc.)
while true; do
    echo "Which assignment are you submitting? (Please enter a number from 1 to 12):"
    read ASSIGNMENT_NUMBER

    ASSIGNMENT_FOLDER="Assignment$ASSIGNMENT_NUMBER"

    # Check if the assignment folder already exists
    if [ -d "$ASSIGNMENT_FOLDER" ]; then
        # Assignment folder exists, ask for confirmation to overwrite
        echo "You have already submitted Assignment$ASSIGNMENT_NUMBER."
        echo "Do you want to overwrite the existing files? (yes/no)"
        read CONFIRM_OVERWRITE

        if [[ "$CONFIRM_OVERWRITE" =~ ^(yes|y)$ ]]; then
            # User confirmed, proceed to overwrite
            echo "Overwriting Assignment$ASSIGNMENT_NUMBER..."
            rm -rf "$ASSIGNMENT_FOLDER"/*
            break  # Proceed to copy files and submit
        else
            echo "Please enter another assignment number."
        fi
    else
        # Assignment folder does not exist, proceed normally
        echo "You are submitting Assignment$ASSIGNMENT_NUMBER."
        break  # Exit the loop and proceed with submission
    fi
done

# Create the assignment folder if it does not exist
if [ ! -d "$ASSIGNMENT_FOLDER" ]; then
    mkdir "$ASSIGNMENT_FOLDER"
    echo "Created folder $ASSIGNMENT_FOLDER."
fi

# Copy all files from the current directory (the assignment folder) into the assignment folder in the cloned repository
echo "Copying assignment files into $ASSIGNMENT_FOLDER..."
rsync -av --exclude="$STUDENT_ID" ../ "$ASSIGNMENT_FOLDER"/

# Add all files to Git
echo "Adding files..."
git add .

# Get the current date and time for the commit message
CURRENT_DATETIME=$(date +"%Y-%m-%d %H:%M:%S")

# Commit the changes with a message including the date and time and assignment number
echo "Committing changes..."
git commit -m "Submitting Assignment$ASSIGNMENT_NUMBER on $CURRENT_DATETIME"

# Push the changes to the remote repository (Git will prompt for username and password)
echo "Pushing changes to GitLab..."
git push

# Check if the push was successful
if [ $? -eq 0 ]; then
    echo "Assignment$ASSIGNMENT_NUMBER submitted successfully!"
else
    echo "Error: Could not push the changes. Please check your internet connection or repository status."
fi

# Clean up: Remove the cloned repository
cd ..
rm -rf "$STUDENT_ID"

